@@ -2,6 +2,8 @@
 #  include <config.h>
 #endif
 
+#include <stdbool.h>
+#include <unistd.h>
 #include <gtk/gtk.h>
 
 #include "interface.h"
@@ -9,7 +11,7 @@
 #include "stock.h"
 #include "engine.h"
 
-static char *id = "@(#) $Id: gtk-lshw.c 1818 2007-08-05 21:11:59Z lyonel $";
+static char *id = "@(#) $Id: gtk-lshw.c 1907 2007-10-13 22:23:16Z lyonel $";
 
 GtkWidget *mainwindow;
 
@@ -26,6 +28,26 @@ main (int argc, char *argv[])
   gtk_set_locale ();
   gtk_init (&argc, &argv);
 
+  if(geteuid() != 0)
+  {
+    bool proceed = false;
+    GtkWidget *dialog = gtk_message_dialog_new (NULL,
+				GTK_DIALOG_MODAL,
+				GTK_MESSAGE_WARNING,
+				GTK_BUTTONS_NONE,
+				"Executing this program as a normal user will give incomplete and maybe erroneous information.");
+    gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+                                  GTK_STOCK_QUIT, GTK_RESPONSE_CANCEL,
+                                  GTK_STOCK_EXECUTE, GTK_RESPONSE_ACCEPT,
+                                  NULL);
+
+    proceed = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT);
+    gtk_widget_destroy (dialog);
+
+    if(!proceed)
+      return -1;
+  }
+
   lshw_gtk_stock_init();
 
 /*
@@ -41,7 +63,7 @@ main (int argc, char *argv[])
     NULL);
   if(GDK_IS_PIXBUF(icon))
   {
-    gtk_window_set_icon(mainwindow, icon);
+    gtk_window_set_icon(GTK_WINDOW(mainwindow), icon);
     gtk_window_set_default_icon(icon);
   }
 
